@@ -183,7 +183,7 @@ pub fn dynamize(_attr: TokenStream, input: TokenStream) -> TokenStream {
                     MethodError::AssocTypeInInputs => {
                         return abort!(
                             span,
-                            "dynamize does not support associated types in parameter types"
+                            "dynamize does not support associated types in parameter types (except in Fn arguments)"
                         )
                     }
                     MethodError::ImplTraitInInputs => {
@@ -473,6 +473,15 @@ impl TypeTransform {
                     quote! {#arg.map_err(|x| #err_inner)}
                 }
             }
+            TypeTransform::Tuple(types) => {
+                let idents = (0..types.len()).map(|i| format_ident!("v{}", i));
+                // FUTURE: let transforms = std::iter::zip(idents, types).map(|(i, t)| t.convert(quote! {#i}));
+                let transforms = types.iter().enumerate().map(|(idx, t)| {
+                    let id = format_ident!("v{}", idx);
+                    t.convert(quote! {#id})
+                });
+                quote! { {let (#(#idents),*) = #arg; (#(#transforms),*)} }
+            }
             TypeTransform::IntoIterMapCollect(types) => {
                 let idents = (0..types.len()).map(|i| format_ident!("v{}", i));
                 // FUTURE: let transforms = std::iter::zip(idents, types).map(|(i, t)| t.convert(quote! {#i}));
